@@ -1,5 +1,5 @@
 import abc
-from typing import Generator, Tuple
+from typing import Iterator, Tuple
 
 import requests
 
@@ -12,9 +12,7 @@ class Client(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def download_sessions(
-        self, package: str
-    ) -> Tuple[Generator[bytes, None, None], int]:
+    def download_sessions(self, package: str) -> Tuple[Iterator[bytes], int]:
         pass
 
 
@@ -22,9 +20,7 @@ class FakeClient(Client):
     def upload_session(self, session: Session, package: str) -> None:
         pass
 
-    def download_sessions(
-        self, package: str
-    ) -> Tuple[Generator[bytes, None, None], int]:
+    def download_sessions(self, package: str) -> Tuple[Iterator[bytes], int]:
         raise NotImplementedError
 
 
@@ -34,11 +30,9 @@ class ProductionClient(Client):
     CHUNK_SIZE = 1024
 
     def upload_session(self, session: Session, package: str) -> None:
-        requests.post(f"{self.ENDPOINT}/packages/{package}", json=session.dict())
+        requests.post(f"{self.ENDPOINT}/packages/{package}", data=session.json())
 
-    def download_sessions(
-        self, package: str
-    ) -> Tuple[Generator[bytes, None, None], int]:
+    def download_sessions(self, package: str) -> Tuple[Iterator[bytes], int]:
         response = requests.get(f"{self.ENDPOINT}/packages/{package}", stream=True)
         size = int(response.headers["Content-Length"])
         content_stream = response.iter_content(chunk_size=self.CHUNK_SIZE)
