@@ -31,8 +31,7 @@ def metadata(function: Callable[[], Dict[str, str]]):
     if package in session.metadata:
         raise RuntimeError
 
-    metadata = function()
-    session.metadata[package] = metadata
+    session.metadata[package] = function()
 
     return function
 
@@ -47,7 +46,6 @@ def collect(
     Arguments:
         function: The function you want to collect usage data on.
         labels: A list of strings you'd like to label this function with.
-        secrets: The names of parameters that are sensitive.
 
     Examples:
         Aasdf
